==> vue-nav-menu-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/nav-menu/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { iconSetting, iconChevronRight, iconSandwichCollapse, iconSandwichExpand } from "@dftvue2-opentiny/vue-icon";
import Tooltip from "@dftvue2-opentiny/vue-tooltip";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["data", "parentKey", "overflow", "beforeSkip", "fetchMenuData", "fields", "prevent", "allowFullUrl"]),
  components: {
    TinyTooltip: Tooltip,
    IconSetting: iconSetting(),
    IconChevronRight: iconChevronRight(),
    IconSandwichCollapse: iconSandwichCollapse(),
    IconSandwichExpand: iconSandwichExpand()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "navMenu",
    staticClass: "tiny-nav-menu"
  }, [/^(retract|fixed)$/.test(_vm.overflow) ? _c("div", {
    staticClass: "more-button",
    class: {
      mobile: _vm.slots["mobile-menu"]
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.showSubMenu(_vm.state.data[0].children, {
          more: true
        });
      },
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_c(_vm.state.showMore ? "IconSandwichExpand" : "IconSandwichCollapse", {
    tag: "component"
  })], 1) : _vm._e(), _vm.slots.logo ? _c("div", {
    staticClass: "slot-logo"
  }, [_vm._t("logo")], 2) : _vm._e(), _c("div", {
    staticClass: "menu-container"
  }, [_vm.state.data && _vm.state.data.length ? _c("ul", {
    staticClass: "menu",
    style: _vm.state.isSaaSTheme ? {} : _vm.state.menuStyle
  }, _vm._l(_vm.state.data, function(item, index) {
    return _c("li", {
      key: index + (item.title || "")
    }, [_c(_vm.getTag(item), {
      tag: "component",
      class: {
        active: index === _vm.state.activeIndex,
        selected: index === _vm.state.selectedIndex
      },
      attrs: {
        "to": _vm.getRoute(item)
      },
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.showSubMenu(item.children, {
            index
          }, $event);
        },
        "mouseleave": _vm.willHideSubMenu,
        "click": function click($event) {
          return _vm.clickMenu(item, index);
        }
      }
    }, [_vm._v(_vm._s(item.title))])], 1);
  }), 0) : _vm._e()]), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isShowMore,
      expression: "state.isShowMore"
    }],
    staticClass: "more",
    style: {
      marginLeft: _vm.state.marginLeft + "px"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.showSubMenu(_vm.state.more[0].children, {
          more: true
        });
      },
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.navMenu.moreText")) + " ")]), _vm.slots.toolbar ? _c("div", {
    staticClass: "slot-toolbar"
  }, [_vm._t("toolbar")], 2) : _vm._e(), _vm.slots["mobile-menu"] ? _c("div", {
    staticClass: "slot-mobile-menu"
  }, [_vm._t("mobile-menu")], 2) : _vm._e(), _c("transition", {
    attrs: {
      "name": "tiny-transition-zoom-in-top",
      "mode": "out-in"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.showPopmenu,
      expression: "state.showPopmenu"
    }],
    staticClass: "popmenu tiny-min-scrollbar",
    class: [_vm.state.popClass, {
      slide: _vm.state.showPopmenu
    }, {
      "show-left-menu": _vm.state.showMore
    }],
    style: _vm.state.popStyle,
    on: {
      "mouseenter": _vm.stopHideSubMenu,
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_vm.state.showMore ? _c("div", {
    staticClass: "more-menu"
  }, [_c("ul", _vm._l(_vm.state.more, function(item, index) {
    return _c("li", {
      key: index + (item.title || ""),
      class: {
        active: index === _vm.state.subActiveIndex,
        selected: index === _vm.state.moreItemSelectedIndex
      }
    }, [_c(_vm.getTag(item), {
      tag: "component",
      class: {
        showicon: item.children
      },
      attrs: {
        "to": _vm.getRoute(item)
      },
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.setSubMenu(item.children, index);
        },
        "mouseleave": _vm.leaveMoreMune,
        "click": function click($event) {
          return _vm.clickMenu(item, index);
        }
      }
    }, [_vm._v(" " + _vm._s(item.title) + " ")]), item.children ? _c("icon-chevron-right", {
      staticClass: "more-icon"
    }) : _vm._e()], 1);
  }), 0)]) : _vm._e(), _vm.state.subMenus && _vm.state.subMenus.length ? _c("div", {
    staticClass: "sub-menu",
    class: {
      "full-width": !_vm.state.showMore
    }
  }, [_c("ul", {
    staticClass: "sub-menu-ul"
  }, _vm._l(_vm.state.subMenus, function(group, index) {
    return _c("li", {
      key: index + (group.title || ""),
      staticClass: "sub-menu-li",
      class: {
        "col-xs-24 col-sm-12 col-md-8 col-lg-6 col-xl-4": !_vm.state.isSaaSTheme && !_vm.state.popClass.includes("single")
      }
    }, [_c("ul", {
      staticClass: "group"
    }, [_c("li", {
      staticClass: "tiny-nav-menu__sub-menu-title",
      class: !!group.title ? "" : "tiny-nav-menu__sub-menu-title-blank"
    }, [_c(_vm.getTag(group), {
      tag: "component",
      class: {
        selected: index === _vm.state.subIndex && _vm.state.subItemSelectedIndex === -1
      },
      attrs: {
        "to": _vm.getRoute(group)
      },
      on: {
        "click": function click($event) {
          return _vm.clickMenu(group, -1, index);
        },
        "mouseenter": function mouseenter($event) {
          return _vm.handleTitleMouseenter($event);
        },
        "mouseleave": _vm.handleTitleMouseleave
      }
    }, [_vm._v(" " + _vm._s(group.title) + " ")]), group.url ? _c("icon-chevron-right", {
      staticClass: "go-to-icon"
    }) : _vm._e()], 1), _vm._l(group.children, function(item, i) {
      return _c("li", {
        key: i + (item.title || ""),
        staticClass: "sub-item",
        class: {
          "only-secondary-title": !group.title && !_vm.state.subMenu[i].children,
          "third-title": item.children && item.children.length
        }
      }, [_c(_vm.getTag(item), {
        tag: "component",
        class: {
          selected: i === _vm.state.subItemSelectedIndex && index === _vm.state.subIndex
        },
        attrs: {
          "to": _vm.getRoute(item)
        },
        on: {
          "click": function click($event) {
            return _vm.clickMenu(item, i, index);
          }
        }
      }, [_vm._v(" " + _vm._s(item.title) + " ")]), item.children && item.children.length ? _c("ul", _vm._l(item.children, function(subItem, j) {
        return _c("li", {
          key: j + (subItem.title || ""),
          staticClass: "sub-item"
        }, [_c(_vm.getTag(subItem), {
          tag: "component",
          attrs: {
            "to": _vm.getRoute(subItem)
          },
          on: {
            "click": function click($event) {
              return _vm.clickMenu(subItem);
            }
          }
        }, [_vm._v(" " + _vm._s(subItem.title) + " ")])], 1);
      }), 0) : _vm._e()], 1);
    })], 2)]);
  }), 0)]) : _vm._e()])]), _c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "manual": true,
      "effect": "light",
      "content": _vm.state.tooltipContent,
      "placement": "top"
    },
    model: {
      value: _vm.state.tooltipVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tooltipVisible", $$v);
      },
      expression: "state.tooltipVisible"
    }
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-nav-menu-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/nav-menu/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconSetting, iconChevronRight, iconSandwichCollapse, iconSandwichExpand } from '@opentinyvue/vue-icon';
import Tooltip from '@opentinyvue/vue-tooltip';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["data", "parentKey", "overflow", "beforeSkip", "fetchMenuData", "fields", "prevent", "allowFullUrl", "defaultActive"]),
  components: {
    TinyTooltip: Tooltip,
    IconSetting: iconSetting(),
    IconChevronRight: iconChevronRight(),
    IconSandwichCollapse: iconSandwichCollapse(),
    IconSandwichExpand: iconSandwichExpand()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "navMenu",
    staticClass: "tiny-nav-menu"
  }, [/^(retract|fixed)$/.test(_vm.overflow) ? _c("div", {
    staticClass: "more-button",
    class: {
      mobile: _vm.slots["mobile-menu"]
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.showSubMenu(_vm.state.data[0].children, {
          more: true
        });
      },
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_c(_vm.state.showMore ? "IconSandwichExpand" : "IconSandwichCollapse", {
    tag: "component"
  })], 1) : _vm._e(), _vm.slots.logo ? _c("div", {
    staticClass: "slot-logo"
  }, [_vm._t("logo")], 2) : _vm._e(), _c("div", {
    staticClass: "menu-container"
  }, [_vm.state.data && _vm.state.data.length ? _c("ul", {
    staticClass: "menu",
    style: _vm.state.isSaaSTheme ? {} : _vm.state.menuStyle
  }, _vm._l(_vm.state.data, function(item, index) {
    return _c("li", {
      key: index + (item.title || "")
    }, [_c(_vm.getTag(item), {
      tag: "component",
      class: {
        active: index === _vm.state.activeIndex,
        selected: _vm.getTabSelected(item, index)
      },
      attrs: {
        "to": _vm.getRoute(item)
      },
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.showSubMenu(item.children, {
            index
          }, $event);
        },
        "mouseleave": _vm.willHideSubMenu,
        "click": function click($event) {
          return _vm.clickMenu(item, index);
        }
      }
    }, [_vm._v(_vm._s(item.title))])], 1);
  }), 0) : _vm._e()]), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isShowMore,
      expression: "state.isShowMore"
    }],
    class: {
      more: true,
      selected: _vm.state.enterMoreMenu || _vm.getMoreSelected()
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.showSubMenu(_vm.state.more[0].children, {
          more: true
        });
      },
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.navMenu.moreText")) + " ")]), _vm.slots.toolbar ? _c("div", {
    staticClass: "slot-toolbar"
  }, [_vm._t("toolbar")], 2) : _vm._e(), _vm.slots["mobile-menu"] ? _c("div", {
    staticClass: "slot-mobile-menu"
  }, [_vm._t("mobile-menu")], 2) : _vm._e(), _c("transition", {
    attrs: {
      "name": "tiny-transition-zoom-in-top",
      "mode": "out-in"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.showPopmenu,
      expression: "state.showPopmenu"
    }],
    staticClass: "popmenu tiny-min-scrollbar",
    class: [_vm.state.popClass, {
      slide: _vm.state.showPopmenu
    }, {
      "show-left-menu": _vm.state.showMore
    }],
    style: _vm.state.popStyle,
    on: {
      "mouseenter": _vm.stopHideSubMenu,
      "mouseleave": _vm.willHideSubMenu
    }
  }, [_vm.state.showMore ? _c("div", {
    staticClass: "more-menu"
  }, [_c("ul", _vm._l(_vm.state.more, function(item, index) {
    return _c("li", {
      key: index + (item.title || ""),
      class: {
        active: index === _vm.state.subActiveIndex,
        selected: _vm.getLeftSelected(item, index)
      }
    }, [_c(_vm.getTag(item), {
      tag: "component",
      class: {
        showicon: item.children
      },
      attrs: {
        "to": _vm.getRoute(item)
      },
      on: {
        "mouseenter": function mouseenter($event) {
          return _vm.setSubMenu(item.children, index);
        },
        "mouseleave": _vm.leaveMoreMune,
        "click": function click($event) {
          return _vm.clickMenu(item, index);
        }
      }
    }, [_vm._v(" " + _vm._s(item.title) + " ")]), item.children ? _c("icon-chevron-right", {
      staticClass: "more-icon"
    }) : _vm._e()], 1);
  }), 0)]) : _vm._e(), _vm.state.subMenus && _vm.state.subMenus.length ? _c("div", {
    staticClass: "sub-menu",
    class: {
      "full-width": !_vm.state.showMore
    }
  }, [_c("ul", {
    staticClass: "sub-menu-ul"
  }, _vm._l(_vm.state.subMenus, function(group, index) {
    return _c("li", {
      key: index + (group.title || ""),
      staticClass: "sub-menu-li",
      class: {
        "col-xs-24 col-sm-12 col-md-8 col-lg-6 col-xl-4": !_vm.state.isSaaSTheme && !_vm.state.popClass.includes("single")
      }
    }, [_c("ul", {
      staticClass: "group"
    }, [_c("li", {
      staticClass: "tiny-nav-menu__sub-menu-title",
      class: !!group.title ? "" : "tiny-nav-menu__sub-menu-title-blank"
    }, [_c(_vm.getTag(group), {
      tag: "component",
      class: {
        selected: index === _vm.state.subIndex && _vm.state.subItemSelectedIndex === -1
      },
      attrs: {
        "to": _vm.getRoute(group)
      },
      on: {
        "click": function click($event) {
          return _vm.clickMenu(group, -1, index);
        },
        "mouseenter": function mouseenter($event) {
          return _vm.handleTitleMouseenter($event);
        },
        "mouseleave": _vm.handleTitleMouseleave
      }
    }, [_vm._v(" " + _vm._s(group.title) + " ")]), group.url ? _c("icon-chevron-right", {
      staticClass: "go-to-icon"
    }) : _vm._e()], 1), _vm._l(group.children, function(item, i) {
      return _c("li", {
        key: i + (item.title || ""),
        staticClass: "sub-item",
        class: {
          "only-secondary-title": !group.title && !_vm.state.subMenu[i].children,
          "third-title": item.children && item.children.length
        }
      }, [_c(_vm.getTag(item), {
        tag: "component",
        class: {
          selected: _vm.getLastChildSelected(item, i, index)
        },
        attrs: {
          "to": _vm.getRoute(item)
        },
        on: {
          "click": function click($event) {
            return _vm.clickMenu(item, i, index);
          }
        }
      }, [_vm._v(" " + _vm._s(item.title) + " ")]), item.children && item.children.length ? _c("ul", _vm._l(item.children, function(subItem, j) {
        return _c("li", {
          key: j + (subItem.title || ""),
          staticClass: "sub-item"
        }, [_c(_vm.getTag(subItem), {
          tag: "component",
          attrs: {
            "to": _vm.getRoute(subItem)
          },
          on: {
            "click": function click($event) {
              return _vm.clickMenu(subItem);
            }
          }
        }, [_vm._v(" " + _vm._s(subItem.title) + " ")])], 1);
      }), 0) : _vm._e()], 1);
    })], 2)]);
  }), 0)]) : _vm._e()])]), _c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "manual": true,
      "effect": "light",
      "content": _vm.state.tooltipContent,
      "placement": "top"
    },
    model: {
      value: _vm.state.tooltipVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tooltipVisible", $$v);
      },
      expression: "state.tooltipVisible"
    }
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
